@@ -533,7 +533,7 @@ namespace OpenRCT2::Ui::Windows
 
             // Adjust for hidden scrollbars if needed
             auto& mapArea = widgets[WIDX_MAP];
-            if (size.width >= mapArea.width())
+            if (size.width >= mapArea.width() - 1)
                 size.width -= kScrollBarWidth;
             if (size.height >= mapArea.height())
                 size.height -= kScrollBarWidth;
@@ -738,7 +738,7 @@ namespace OpenRCT2::Ui::Windows
 
             // calculate width and height of minimap
             auto& widget = widgets[WIDX_MAP];
-            auto mapWidth = widget.width() - kScrollBarWidth - 1;
+            auto mapWidth = widget.width() - 1 - kScrollBarWidth - 1;
             auto mapHeight = widget.height() - kScrollBarWidth - 1;
 
             centreX = std::max(centreX - (mapWidth >> 1), 0);
@@ -1233,7 +1233,7 @@ namespace OpenRCT2::Ui::Windows
             for (uint32_t i = 0; i < 4; i++)
             {
                 const auto* labelStr = LanguageGetString(MapLabels[i]);
-                _firstColumnWidth = std::max(textOffset + GfxGetStringWidth(labelStr, FontStyle::Medium), _firstColumnWidth);
+                _firstColumnWidth = std::max(textOffset + GfxGetStringWidth(labelStr, FontStyle::medium), _firstColumnWidth);
             }
 
             textOffset += _firstColumnWidth + 4;
@@ -1242,7 +1242,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 const auto* labelStr = LanguageGetString(MapLabels[i]);
                 minWidth = std::max(
-                    static_cast<int16_t>(textOffset + GfxGetStringWidth(labelStr, FontStyle::Medium)), minWidth);
+                    static_cast<int16_t>(textOffset + GfxGetStringWidth(labelStr, FontStyle::medium)), minWidth);
             }
             width = std::max(minWidth, width);
             _recalculateScrollbars = true;
