@@ -45,11 +45,21 @@ using namespace OpenRCT2::TrackMetaData;
 namespace OpenRCT2::Ui::Windows
 {
     static constexpr StringId WindowTitle = kStringIdNone;
-    static constexpr ScreenSize kWindowSize = { 601, 382 };
     static constexpr int32_t kWindowHeightResearch = 194;
     static constexpr int32_t RideListItemsMax = 384;
     static constexpr int32_t RideTabCount = 6;
     static constexpr int32_t GroupByTrackTypeWidth = 172;
+    static constexpr int32_t kScrollItemSize = 116;
+    static constexpr int32_t kMinColCount = 5;
+    static constexpr int32_t kMaxColCount = 15;
+    static constexpr int32_t kMinRowCount = 2;
+    static constexpr int32_t kMaxRowCount = 7;
+    static constexpr int32_t kHorizontalPadding = 21;
+    static constexpr int32_t kVerticalPadding = 150;
+    static constexpr ScreenSize kWindowSize = { (kMinColCount * kScrollItemSize) + kHorizontalPadding,
+                                                (kMinRowCount * kScrollItemSize) + kVerticalPadding };
+    static constexpr ScreenSize kWindowMaxSize = { (kMaxColCount * kScrollItemSize) + kHorizontalPadding,
+                                                   (kMaxRowCount * kScrollItemSize) + kVerticalPadding };
 
 #pragma region Ride type view order
 
@@ -415,7 +425,7 @@ namespace OpenRCT2::Ui::Windows
 
             const auto& ls = OpenRCT2::GetContext()->GetLocalisationService();
             auto string = ls.GetString(STR_GROUP_BY_TRACK_TYPE);
-            auto strWidth = GfxGetStringWidth(string, FontStyle::Medium);
+            auto strWidth = GfxGetStringWidth(string, FontStyle::medium);
             auto localizedGroupByTrackTypeWidth = strWidth + 14;
             widgets[WIDX_GROUP_BY_TRACK_TYPE].left = width - 8 - localizedGroupByTrackTypeWidth;
         }
@@ -447,7 +457,8 @@ namespace OpenRCT2::Ui::Windows
                 count++;
                 listItem++;
             }
-            return { widgets[WIDX_RIDE_LIST].width(), ((count + 4) / 5) * 116 };
+            auto itemsPerRow = getNumImagesPerRow();
+            return { widgets[WIDX_RIDE_LIST].width() - 1, ((count + (itemsPerRow - 1)) / itemsPerRow) * kScrollItemSize };
         }
 
         void onScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
@@ -496,8 +507,8 @@ namespace OpenRCT2::Ui::Windows
                 {
                     const auto borderStyle = isSelected ? Rectangle::BorderStyle::inset : Rectangle::BorderStyle::outset;
                     Rectangle::fillInset(
-                        rt, { coords, coords + ScreenCoordsXY{ 115, 115 } }, colours[1], borderStyle,
-                        Rectangle::FillBrightness::dark);
+                        rt, { coords, coords + ScreenCoordsXY{ kScrollItemSize - 1, kScrollItemSize - 1 } }, colours[1],
+                        borderStyle, Rectangle::FillBrightness::dark);
                 }
 
                 // Draw ride image with feathered border
@@ -506,11 +517,11 @@ namespace OpenRCT2::Ui::Windows
                 GfxDrawSpriteRawMasked(rt, coords + ScreenCoordsXY{ 2, 2 }, mask, rideImage);
 
                 // Next position
-                coords.x += 116;
-                if (coords.x >= 116 * 5 + 1)
+                coords.x += kScrollItemSize;
+                if (coords.x >= kScrollItemSize * getNumImagesPerRow() + 1)
                 {
                     coords.x = 1;
-                    coords.y += 116;
+                    coords.y += kScrollItemSize;
                 }
 
                 // Next item
@@ -809,8 +820,6 @@ namespace OpenRCT2::Ui::Windows
 
         void RefreshWidgetSizing()
         {
-            int32_t newWidth{}, newHeight{};
-
             if (_currentTab < SHOP_TAB)
             {
                 disabledWidgets &= ~(1 << WIDX_GROUP_BY_TRACK_TYPE);
@@ -831,6 +840,7 @@ namespace OpenRCT2::Ui::Windows
                 widgets[WIDX_GROUP_BY_TRACK_TYPE].type = WidgetType::empty;
             }
 
+            ScreenSize newMinSize{}, newMaxSize{};
             if (_currentTab != RESEARCH_TAB)
             {
                 widgets[WIDX_RIDE_LIST].type = WidgetType::scroll;
@@ -841,8 +851,8 @@ namespace OpenRCT2::Ui::Windows
                 widgets[WIDX_LAST_DEVELOPMENT_BUTTON].type = WidgetType::empty;
                 widgets[WIDX_RESEARCH_FUNDING_BUTTON].type = WidgetType::empty;
 
-                newWidth = kWindowSize.width;
-                newHeight = kWindowSize.height;
+                newMinSize = kWindowSize;
+                newMaxSize = kWindowMaxSize;
             }
             else
             {
@@ -855,24 +865,35 @@ namespace OpenRCT2::Ui::Windows
                 if (!(getGameState().park.flags & PARK_FLAGS_NO_MONEY))
                     widgets[WIDX_RESEARCH_FUNDING_BUTTON].type = WidgetType::flatBtn;
 
-                newWidth = 300;
-                newHeight = kWindowHeightResearch;
+                newMinSize = { 300, kWindowHeightResearch };
+                newMaxSize = newMinSize;
             }
 
             // Handle new window size
-            if (width != newWidth || height != newHeight)
+            if (width != newMinSize.width || height != newMinSize.height)
             {
-                ScreenSize newSize = { newWidth, newHeight };
-                WindowSetResize(*this, newSize, newSize);
+                WindowSetResize(*this, newMinSize, newMaxSize);
                 onResize();
-
-                widgets[WIDX_GROUP_BY_TRACK_TYPE].left = newWidth - 8 - GroupByTrackTypeWidth;
-                widgets[WIDX_GROUP_BY_TRACK_TYPE].right = newWidth - 8;
             }
 
             initScrollWidgets();
         }
 
+        void onResize() override
+        {
+            widgets[WIDX_GROUP_BY_TRACK_TYPE].left = width - 8 - GroupByTrackTypeWidth;
+            widgets[WIDX_GROUP_BY_TRACK_TYPE].right = width - 8;
+            widgets[WIDX_RIDE_LIST].right = width - 3 - 1;
+            widgets[WIDX_RIDE_LIST].bottom = height - 65;
+        }
+
+        uint8_t getNumImagesPerRow()
+        {
+            const Widget& listWidget = widgets[WIDX_RIDE_LIST];
+            auto scrollWidth = listWidget.width();
+            return scrollWidth / kScrollItemSize;
+        }
+
         RideSelection ScrollGetRideListItemAt(const ScreenCoordsXY& screenCoords)
         {
             RideSelection result;
@@ -882,12 +903,13 @@ namespace OpenRCT2::Ui::Windows
             if (screenCoords.x <= 0 || screenCoords.y <= 0)
                 return result;
 
-            int32_t column = screenCoords.x / 116;
-            int32_t row = screenCoords.y / 116;
-            if (column >= 5)
+            auto itemsPerRow = getNumImagesPerRow();
+            int32_t column = screenCoords.x / kScrollItemSize;
+            int32_t row = screenCoords.y / kScrollItemSize;
+            if (column >= itemsPerRow)
                 return result;
 
-            int32_t index = column + (row * 5);
+            int32_t index = column + (row * itemsPerRow);
 
             RideSelection* listItem = _windowNewRideListItems;
             while (listItem->Type != kRideTypeNull || listItem->EntryIndex != kObjectEntryIndexNull)
@@ -978,7 +1000,7 @@ namespace OpenRCT2::Ui::Windows
 
                 ft = Formatter();
                 ft.Add<money64>(price);
-                DrawTextBasic(rt, screenPos + ScreenCoordsXY{ textWidth, 51 }, stringId, ft, { TextAlignment::RIGHT });
+                DrawTextBasic(rt, screenPos + ScreenCoordsXY{ textWidth - 14, 51 }, stringId, ft, { TextAlignment::right });
             }
 
             // Draw object author(s) if debugging tools are active
@@ -1001,7 +1023,7 @@ namespace OpenRCT2::Ui::Windows
 
                 DrawTextEllipsised(
                     rt, screenPos + ScreenCoordsXY{ textWidth, 0 }, kWindowSize.width - 2, STR_WINDOW_COLOUR_2_STRINGID, ft,
-                    { TextAlignment::RIGHT });
+                    { TextAlignment::right });
             }
         }
 
@@ -1086,7 +1108,8 @@ namespace OpenRCT2::Ui::Windows
         windowMgr->CloseByClass(WindowClass::trackDesignPlace);
 
         window = windowMgr->Create<NewRideWindow>(
-            WindowClass::constructRide, kWindowSize, { WindowFlag::higherContrastOnPress, WindowFlag::autoPosition });
+            WindowClass::constructRide, kWindowSize,
+            { WindowFlag::higherContrastOnPress, WindowFlag::autoPosition, WindowFlag::resizable });
         return window;
     }
 
