@@ -19,6 +19,7 @@
     #include <openrct2/SpriteIds.h>
     #include <openrct2/config/Config.h>
     #include <openrct2/core/Json.hpp>
+    #include <openrct2/drawing/Rectangle.h>
     #include <openrct2/drawing/Text.h>
     #include <openrct2/interface/Colour.h>
     #include <openrct2/localisation/Formatter.h>
@@ -28,6 +29,8 @@
     #include <openrct2/ui/WindowManager.h>
     #include <tuple>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
     static constexpr ScreenSize kMinimumWindowSize = { 500, 288 };
@@ -91,7 +94,7 @@ namespace OpenRCT2::Ui::Windows
 
         void onOpen() override
         {
-            _playerName = Config::Get().network.PlayerName;
+            _playerName = Config::Get().network.playerName;
             setWidgets(_serverListWidgets);
             widgets[WIDX_PLAYER_NAME_INPUT].string = const_cast<utf8*>(_playerName.c_str());
             initScrollWidgets();
@@ -245,7 +248,7 @@ namespace OpenRCT2::Ui::Windows
             }
             else
             {
-                const int32_t iconX = listWidget.width() - kScrollBarWidth - 7 - 10;
+                const int32_t iconX = listWidget.width() - 1 - kScrollBarWidth - 7 - 10;
                 showNetworkVersionTooltip = screenCoords.x > iconX;
             }
 
@@ -275,7 +278,7 @@ namespace OpenRCT2::Ui::Windows
                         return;
 
                     _playerName = temp;
-                    Config::Get().network.PlayerName = _playerName;
+                    Config::Get().network.playerName = _playerName;
                     widgets[WIDX_PLAYER_NAME_INPUT].string = const_cast<utf8*>(_playerName.c_str());
 
                     invalidateWidget(WIDX_PLAYER_NAME_INPUT);
@@ -329,7 +332,7 @@ namespace OpenRCT2::Ui::Windows
             GfxClear(rt, paletteIndex);
 
             auto& listWidget = widgets[WIDX_LIST];
-            int32_t listWidgetWidth = listWidget.width();
+            int32_t listWidgetWidth = listWidget.width() - 1;
 
             ScreenCoordsXY screenCoords;
             screenCoords.y = 0;
@@ -344,7 +347,7 @@ namespace OpenRCT2::Ui::Windows
                 // Draw hover highlight
                 if (highlighted)
                 {
-                    GfxFilterRect(
+                    Rectangle::filter(
                         rt, { 0, screenCoords.y, listWidgetWidth, screenCoords.y + kItemHeight },
                         FilterPaletteID::paletteDarken1);
                     _version = serverDetails.Version;
@@ -368,7 +371,7 @@ namespace OpenRCT2::Ui::Windows
                 {
                     snprintf(players, sizeof(players), "%d/%d", serverDetails.Players, serverDetails.MaxPlayers);
                 }
-                const int16_t numPlayersStringWidth = GfxGetStringWidth(players, FontStyle::Medium);
+                const int16_t numPlayersStringWidth = GfxGetStringWidth(players, FontStyle::medium);
 
                 // How much space we have for the server info depends on the size of everything rendered after.
                 const int16_t spaceAvailableForInfo = listWidgetWidth - numPlayersStringWidth - kScrollBarWidth - 35;
