@@ -18,6 +18,7 @@
 #include <openrct2/SpriteIds.h>
 #include <openrct2/drawing/Rectangle.h>
 #include <openrct2/drawing/Text.h>
+#include <openrct2/interface/ColourWithFlags.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/localisation/Formatting.h>
 #include <openrct2/localisation/StringIds.h>
@@ -453,7 +454,7 @@ namespace OpenRCT2::Ui::Windows
 
                     WindowDropdownShowTextCustomWidth(
                         { windowPos.x + widget->left, windowPos.y + widget->top }, widget->height() + 1, colours[1], 0,
-                        Dropdown::Flag::StayOpen, num_items, widget->width() - 3);
+                        Dropdown::Flag::StayOpen, num_items, widget->width() - 4);
 
                     gDropdown.items[static_cast<int32_t>(ThemeManagerGetAvailableThemeIndex())].setChecked(true);
                     break;
@@ -702,7 +703,7 @@ namespace OpenRCT2::Ui::Windows
                         else
                         {
                             auto colour = ThemeGetColour(wc, _buttonIndex);
-                            colour.setFlag(ColourFlag::translucent, !colour.hasFlag(ColourFlag::translucent));
+                            colour.flags.flip(ColourFlag::translucent);
                             ThemeSetColour(wc, _buttonIndex, colour);
                             ColourSchemeUpdateAll();
 
@@ -721,7 +722,7 @@ namespace OpenRCT2::Ui::Windows
             if (_selectedTab == WINDOW_THEMES_TAB_SETTINGS || _selectedTab == WINDOW_THEMES_TAB_FEATURES)
                 return;
 
-            if (!colours[1].hasFlag(ColourFlag::translucent))
+            if (!colours[1].flags.has(ColourFlag::translucent))
                 // Rectangle::fill(dpi, dpi->x, dpi->y, dpi->x + dpi->width - 1, dpi->y + dpi->height - 1,
                 // ColourMapA[colours[1].colour].mid_light);
                 GfxClear(rt, ColourMapA[colours[1].colour].mid_light);
@@ -759,7 +760,7 @@ namespace OpenRCT2::Ui::Windows
                                                            screenCoords.y + _max_row_height - colorOffset + 1 };
                         auto yPixelOffset = ScreenCoordsXY{ 0, 1 };
 
-                        if (colour.hasFlag(ColourFlag::translucent))
+                        if (colour.flags.has(ColourFlag::translucent))
                         {
                             TranslucentWindowPalette windowPalette = kTranslucentWindowPalettes[colour.colour];
 
@@ -799,10 +800,10 @@ namespace OpenRCT2::Ui::Windows
                         Rectangle::fillInset(
                             rt, { topLeft, bottomRight }, colours[1], Rectangle::BorderStyle::inset,
                             Rectangle::FillBrightness::dark, Rectangle::FillMode::dontLightenWhenInset);
-                        if (colour.hasFlag(ColourFlag::translucent))
+                        if (colour.flags.has(ColourFlag::translucent))
                         {
                             DrawText(
-                                rt, topLeft, { colours[1].colour, FontStyle::Medium, TextDarkness::Dark }, kCheckMarkString);
+                                rt, topLeft, { colours[1].colour, FontStyle::medium, TextDarkness::dark }, kCheckMarkString);
                         }
                     }
                 }
@@ -863,7 +864,7 @@ namespace OpenRCT2::Ui::Windows
 
             std::string str = FormatStringIDLegacy(format, args);
 
-            return GfxGetStringWidth(str, FontStyle::Medium);
+            return GfxGetStringWidth(str, FontStyle::medium);
         }
 
         int8_t GetTotalColoursUpTo(int8_t index)
