@@ -181,7 +181,7 @@ namespace OpenRCT2::Ui::Windows
         {
             const auto& widget = widgets[WIDX_CLIP_HEIGHT_SLIDER];
             const ScrollArea* const scroll = &this->scrolls[0];
-            const int16_t scroll_width = widget.width() - 1;
+            const int16_t scroll_width = widget.width() - 2;
             const uint8_t clip_height = static_cast<uint8_t>(
                 (static_cast<float>(scroll->contentOffsetX) / (scroll->contentWidth - scroll_width)) * 255);
             if (clip_height != gClipHeight)
@@ -316,7 +316,7 @@ namespace OpenRCT2::Ui::Windows
                 case DisplayType::DisplayUnits:
                 {
                     // Print the value in the configured height label type:
-                    if (Config::Get().general.ShowHeightAsUnits)
+                    if (Config::Get().general.showHeightAsUnits)
                     {
                         // Height label is Units.
                         auto ft = Formatter();
@@ -329,7 +329,7 @@ namespace OpenRCT2::Ui::Windows
                     {
                         // Height label is Real Values.
                         // Print the value in the configured measurement units.
-                        switch (Config::Get().general.MeasurementFormat)
+                        switch (Config::Get().general.measurementFormat)
                         {
                             case MeasurementFormat::Metric:
                             case MeasurementFormat::SI:
@@ -402,7 +402,7 @@ namespace OpenRCT2::Ui::Windows
             const auto& widget = widgets[WIDX_CLIP_HEIGHT_SLIDER];
             const float clip_height_ratio = static_cast<float>(gClipHeight) / 255;
             this->scrolls[0].contentOffsetX = static_cast<int16_t>(
-                std::ceil(clip_height_ratio * (this->scrolls[0].contentWidth - (widget.width() - 1))));
+                std::ceil(clip_height_ratio * (this->scrolls[0].contentWidth - (widget.width() - 2))));
         }
 
         bool IsActive()
