@@ -122,7 +122,6 @@ namespace OpenRCT2
     class ReadObjectContext : public IReadObjectContext
     {
     private:
-        IObjectRepository& _objectRepository;
         const IFileDataRetriever* _fileDataRetriever;
 
         std::string _identifier;
@@ -146,11 +145,8 @@ namespace OpenRCT2
             return _wasError;
         }
 
-        ReadObjectContext(
-            IObjectRepository& objectRepository, const std::string& identifier, bool loadImages,
-            const IFileDataRetriever* fileDataRetriever)
-            : _objectRepository(objectRepository)
-            , _fileDataRetriever(fileDataRetriever)
+        ReadObjectContext(const std::string& identifier, bool loadImages, const IFileDataRetriever* fileDataRetriever)
+            : _fileDataRetriever(fileDataRetriever)
             , _identifier(identifier)
             , _loadImages(loadImages)
         {
@@ -161,11 +157,6 @@ namespace OpenRCT2
             return _identifier;
         }
 
-        IObjectRepository& GetObjectRepository() override
-        {
-            return _objectRepository;
-        }
-
         bool ShouldLoadImages() override
         {
             return _loadImages;
@@ -228,23 +219,22 @@ namespace OpenRCT2::ObjectFactory
      * @note jRoot is deliberately left non-const: json_t behaviour changes when const
      */
     static std::unique_ptr<Object> CreateObjectFromJson(
-        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable,
-        const std::string_view path);
+        json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable, const std::string_view path);
 
     static ObjectSourceGame ParseSourceGame(const std::string_view s)
     {
         static const std::unordered_map<std::string_view, ObjectSourceGame> LookupTable{
-            { "rct1", ObjectSourceGame::RCT1 },
-            { "rct1aa", ObjectSourceGame::AddedAttractions },
-            { "rct1ll", ObjectSourceGame::LoopyLandscapes },
-            { "rct2", ObjectSourceGame::RCT2 },
-            { "rct2ww", ObjectSourceGame::WackyWorlds },
-            { "rct2tt", ObjectSourceGame::TimeTwister },
-            { "official", ObjectSourceGame::OpenRCT2Official },
-            { "custom", ObjectSourceGame::Custom },
+            { "rct1", ObjectSourceGame::rct1 },
+            { "rct1aa", ObjectSourceGame::addedAttractions },
+            { "rct1ll", ObjectSourceGame::loopyLandscapes },
+            { "rct2", ObjectSourceGame::rct2 },
+            { "rct2ww", ObjectSourceGame::wackyWorlds },
+            { "rct2tt", ObjectSourceGame::timeTwister },
+            { "official", ObjectSourceGame::openRCT2Official },
+            { "custom", ObjectSourceGame::custom },
         };
         auto result = LookupTable.find(s);
-        return (result != LookupTable.end()) ? result->second : ObjectSourceGame::Custom;
+        return (result != LookupTable.end()) ? result->second : ObjectSourceGame::custom;
     }
 
     static void ReadObjectLegacy(Object& object, IReadObjectContext* context, OpenRCT2::IStream* stream)
@@ -256,15 +246,37 @@ namespace OpenRCT2::ObjectFactory
         catch (const IOException&)
         {
             // TODO check that ex is really EOF and not some other error
-            context->LogError(ObjectError::UnexpectedEOF, "Unexpectedly reached end of file.");
+            context->LogError(ObjectError::unexpectedEOF, "Unexpectedly reached end of file.");
         }
         catch (const std::exception&)
         {
-            context->LogError(ObjectError::Unknown, nullptr);
+            context->LogError(ObjectError::unknown, nullptr);
         }
     }
 
-    std::unique_ptr<Object> CreateObjectFromLegacyFile(IObjectRepository& objectRepository, const utf8* path, bool loadImages)
+    std::unique_ptr<Object> CreateObjectFromFile(u8string_view path, bool loadImages)
+    {
+        std::unique_ptr<Object> object;
+        auto extension = Path::GetExtension(path);
+        if (String::iequals(extension, ".json"))
+        {
+            auto pathStr = u8string(path);
+            object = ObjectFactory::CreateObjectFromJsonFile(pathStr, loadImages);
+        }
+        else if (String::iequals(extension, ".parkobj"))
+        {
+            object = ObjectFactory::CreateObjectFromZipFile(path, loadImages);
+        }
+        else
+        {
+            auto pathStr = u8string(path);
+            object = ObjectFactory::CreateObjectFromLegacyFile(pathStr.c_str(), loadImages);
+        }
+
+        return object;
+    }
+
+    std::unique_ptr<Object> CreateObjectFromLegacyFile(const utf8* path, bool loadImages)
     {
         LOG_VERBOSE("CreateObjectFromLegacyFile(..., \"%s\")", path);
 
@@ -290,7 +302,7 @@ namespace OpenRCT2::ObjectFactory
                 LOG_VERBOSE("  size: %zu", chunk->GetLength());
 
                 auto chunkStream = OpenRCT2::MemoryStream(chunk->GetData(), chunk->GetLength());
-                auto readContext = ReadObjectContext(objectRepository, objectName, loadImages, nullptr);
+                auto readContext = ReadObjectContext(objectName, loadImages, nullptr);
                 ReadObjectLegacy(*result, &readContext, &chunkStream);
                 if (readContext.WasError())
                 {
@@ -306,8 +318,7 @@ namespace OpenRCT2::ObjectFactory
         return result;
     }
 
-    std::unique_ptr<Object> CreateObjectFromLegacyData(
-        IObjectRepository& objectRepository, const RCTObjectEntry* entry, const void* data, size_t dataSize)
+    std::unique_ptr<Object> CreateObjectFromLegacyData(const RCTObjectEntry* entry, const void* data, size_t dataSize)
     {
         Guard::ArgumentNotNull(entry, GUARD_LINE);
         Guard::ArgumentNotNull(data, GUARD_LINE);
@@ -320,7 +331,7 @@ namespace OpenRCT2::ObjectFactory
             utf8 objectName[kDatNameLength + 1];
             ObjectEntryGetNameFixed(objectName, sizeof(objectName), entry);
 
-            auto readContext = ReadObjectContext(objectRepository, objectName, !gOpenRCT2NoGraphics, nullptr);
+            auto readContext = ReadObjectContext(objectName, !gOpenRCT2NoGraphics, nullptr);
             auto chunkStream = OpenRCT2::MemoryStream(data, dataSize);
             ReadObjectLegacy(*result, &readContext, &chunkStream);
 
@@ -434,7 +445,7 @@ namespace OpenRCT2::ObjectFactory
         { "climate", ObjectType::climate },
     };
 
-    std::unique_ptr<Object> CreateObjectFromZipFile(IObjectRepository& objectRepository, std::string_view path, bool loadImages)
+    std::unique_ptr<Object> CreateObjectFromZipFile(std::string_view path, bool loadImages)
     {
         try
         {
@@ -450,7 +461,7 @@ namespace OpenRCT2::ObjectFactory
             if (jRoot.is_object())
             {
                 auto fileDataRetriever = ZipDataRetriever(path, *archive);
-                return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages, path);
+                return CreateObjectFromJson(jRoot, &fileDataRetriever, loadImages, path);
             }
         }
         catch (const std::exception& e)
@@ -460,8 +471,7 @@ namespace OpenRCT2::ObjectFactory
         return nullptr;
     }
 
-    std::unique_ptr<Object> CreateObjectFromJsonFile(
-        IObjectRepository& objectRepository, const std::string& path, bool loadImages)
+    std::unique_ptr<Object> CreateObjectFromJsonFile(const std::string& path, bool loadImages)
     {
         LOG_VERBOSE("CreateObjectFromJsonFile(\"%s\")", path.c_str());
 
@@ -469,7 +479,7 @@ namespace OpenRCT2::ObjectFactory
         {
             json_t jRoot = Json::ReadFromFile(path.c_str());
             auto fileDataRetriever = FileSystemDataRetriever(Path::GetDirectory(path));
-            return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages, path);
+            return CreateObjectFromJson(jRoot, &fileDataRetriever, loadImages, path);
         }
         catch (const std::runtime_error& err)
         {
@@ -496,18 +506,18 @@ namespace OpenRCT2::ObjectFactory
             else
             {
                 LOG_ERROR("Object %s has an incorrect sourceGame parameter.", id.c_str());
-                result.SetSourceGames({ ObjectSourceGame::Custom });
+                result.SetSourceGames({ ObjectSourceGame::custom });
             }
         }
         // >90% of objects are custom, so allow omitting the parameter without displaying an error.
         else if (sourceGames.is_null())
         {
-            result.SetSourceGames({ ObjectSourceGame::Custom });
+            result.SetSourceGames({ ObjectSourceGame::custom });
         }
         else
         {
             LOG_ERROR("Object %s has an incorrect sourceGame parameter.", id.c_str());
-            result.SetSourceGames({ ObjectSourceGame::Custom });
+            result.SetSourceGames({ ObjectSourceGame::custom });
         }
     }
 
@@ -518,8 +528,7 @@ namespace OpenRCT2::ObjectFactory
     }
 
     std::unique_ptr<Object> CreateObjectFromJson(
-        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable,
-        const std::string_view path)
+        json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable, const std::string_view path)
     {
         if (!jRoot.is_object())
         {
@@ -580,7 +589,7 @@ namespace OpenRCT2::ObjectFactory
             result->SetDescriptor(descriptor);
             result->SetFileName(OpenRCT2::Path::GetFileNameWithoutExtension(path));
             result->MarkAsJsonObject();
-            auto readContext = ReadObjectContext(objectRepository, id, loadImageTable, fileRetriever);
+            auto readContext = ReadObjectContext(id, loadImageTable, fileRetriever);
             result->ReadJson(&readContext, jRoot);
             if (readContext.WasError())
             {
