@@ -30,204 +30,204 @@ namespace OpenRCT2::RCT1
 
     enum class RideType : uint8_t
     {
-        WoodenRollerCoaster = 0,
-        StandUpSteelRollerCoaster,
-        SuspendedRollerCoaster,
-        InvertedRollerCoaster,
-        SteelMiniRollerCoaster,
-        MiniatureRailway,
-        Monorail,
-        SuspendedSingleRailRollerCoaster,
-        BoatHire,
-        WoodenCrazyRodentRollerCoaster,
-        SingleRailRollerCoaster,
-        CarRide,
-        LaunchedFreefall,
-        BobsledRollerCoaster,
-        ObservationTower,
-        SteelRollerCoaster,
-        WaterSlide,
-        MineTrainRollerCoaster,
-        Chairlift,
-        SteelCorkscrewRollerCoaster,
-        HedgeMaze,
-        SpiralSlide,
-        GoKarts,
-        LogFlume,
-        RiverRapids,
-        Dodgems,
-        SwingingShip,
-        SwingingInverterShip,
-        IceCreamStall,
-        ChipsStall,
-        DrinkStall,
-        CandyflossStall,
-        BurgerBar,
-        MerryGoRound,
-        BalloonStall,
-        InformationKiosk,
-        Toilets,
-        FerrisWheel,
-        MotionSimulator,
+        woodenRollerCoaster = 0,
+        standUpSteelRollerCoaster,
+        suspendedRollerCoaster,
+        invertedRollerCoaster,
+        steelMiniRollerCoaster,
+        miniatureRailway,
+        monorail,
+        suspendedSingleRailRollerCoaster,
+        boatHire,
+        woodenCrazyRodentRollerCoaster,
+        singleRailRollerCoaster,
+        carRide,
+        launchedFreefall,
+        bobsledRollerCoaster,
+        observationTower,
+        steelRollerCoaster,
+        waterSlide,
+        mineTrainRollerCoaster,
+        chairlift,
+        steelCorkscrewRollerCoaster,
+        hedgeMaze,
+        spiralSlide,
+        goKarts,
+        logFlume,
+        riverRapids,
+        dodgems,
+        swingingShip,
+        swingingInverterShip,
+        iceCreamStall,
+        chipsStall,
+        drinkStall,
+        candyflossStall,
+        burgerBar,
+        merryGoRound,
+        balloonStall,
+        informationKiosk,
+        toilets,
+        ferrisWheel,
+        motionSimulator,
         _3DCinema,
-        TopSpin,
-        SpaceRings,
-        ReverseFreefallRollerCoaster,
-        SouvenirStall,
-        VerticalRollerCoaster,
-        PizzaStall,
-        Twist,
-        HauntedHouse,
-        PopcornStall,
-        Circus,
-        GhostTrain,
-        SteelTwisterRollerCoaster,
-        WoodenTwisterRollerCoaster,
-        WoodenSideFrictionRollerCoaster,
-        SteelWildMouseRollerCoaster,
-        HotDogStall,
-        ExoticSeaFoodStall,
-        HatStall,
-        ToffeeAppleStall,
-        VirginiaReel,
-        RiverRide,
-        CycleMonorail,
-        FlyingRollerCoaster,
-        SuspendedMonorail,
+        topSpin,
+        spaceRings,
+        reverseFreefallRollerCoaster,
+        souvenirStall,
+        verticalRollerCoaster,
+        pizzaStall,
+        twist,
+        hauntedHouse,
+        popcornStall,
+        circus,
+        ghostTrain,
+        steelTwisterRollerCoaster,
+        woodenTwisterRollerCoaster,
+        woodenSideFrictionRollerCoaster,
+        steelWildMouseRollerCoaster,
+        hotDogStall,
+        exoticSeaFoodStall,
+        hatStall,
+        toffeeAppleStall,
+        virginiaReel,
+        riverRide,
+        cycleMonorail,
+        flyingRollerCoaster,
+        suspendedMonorail,
         _40,
-        WoodenReverseRollerCoaster,
-        HeartlineTwisterRollerCoaster,
-        MiniatureGolf,
+        woodenReverseRollerCoaster,
+        heartlineTwisterRollerCoaster,
+        miniatureGolf,
         _44,
-        RotoDrop,
-        FlyingSaucers,
-        CrookedHouse,
-        CycleRailway,
-        SuspendedLoopingRollerCoaster,
-        WaterCoaster,
-        AirPoweredVerticalCoaster,
-        InvertedWildMouseCoaster,
-        JetSkis,
-        TShirtStall,
-        RaftRide,
-        DoughnutShop,
-        Enterprise,
-        CoffeeShop,
-        FriedChickenStall,
-        LemonadeStall,
+        rotoDrop,
+        flyingSaucers,
+        crookedHouse,
+        cycleRailway,
+        suspendedLoopingRollerCoaster,
+        waterCoaster,
+        airPoweredVerticalCoaster,
+        invertedWildMouseCoaster,
+        jetSkis,
+        tShirtStall,
+        raftRide,
+        doughnutShop,
+        enterprise,
+        coffeeShop,
+        friedChickenStall,
+        lemonadeStall,
 
-        Count,
-        Null = 255,
+        count,
+        null = 255,
     };
 
     enum class VehicleType : uint8_t
     {
-        SteelRollerCoasterTrain,
-        SteelRollerCoasterTrainBackwards,
-        WoodenRollerCoasterTrain,
-        InvertedCoasterTrain, // Not in RCT2
-        SuspendedSwingingCars,
-        LadybirdCars,
-        StandUpRollerCoasterCars,
-        SpinningCars,
-        SinglePersonSwingingChairs,
-        SwansPedalBoats,
-        LargeMonorailTrain,
-        Canoes,
-        RowingBoats,
-        SteamTrain,
-        WoodenMouseCars,
-        BumperBoats,
-        WoodenRollerCoasterTrainBackwards,
-        RocketCars,
-        Horses, // Steeplechase
-        Sportscars,
-        LyingDownSwingingCars, // Inverted single-rail
-        WoodenMineCars,
-        SuspendedSwingingAirplaneCars,
-        SmallMonorailCars,
-        WaterTricycles,
-        LaunchedFreefallCar,
-        BobsleighCars,
-        Dinghies,
-        RotatingCabin,
-        MineTrain,
-        ChairliftCars,
-        CorkscrewRollerCoasterTrain,
-        Motorbikes,
-        RacingCars,
-        Trucks,
-        GoKarts,
-        RapidsBoats,
-        LogFlumeBoats,
-        Dodgems,
-        SwingingShip,
-        SwingingInverterShip,
-        MerryGoRound,
-        FerrisWheel,
-        SimulatorPod,
-        CinemaBuilding,
-        TopspinCar,
-        SpaceRings,
-        ReverseFreefallRollerCoasterCar,
-        VerticalRollerCoasterCars,
-        CatCars,
-        TwistArmsAndCars,
-        HauntedHouseBuilding,
-        LogCars,
-        CircusTent,
-        GhostTrainCars,
-        SteelTwisterRollerCoasterTrain,
-        WoodenTwisterRollerCoasterTrain,
-        WoodenSideFrictionCars,
-        VintageCars,
-        SteamTrainCoveredCars,
-        StandUpSteelTwisterRollerCoasterTrain,
-        FloorlessSteelTwisterRollerCoasterTrain,
-        SteelMouseCars,
-        ChairliftCarsAlternative,
-        SuspendedMonorailTrain,
-        HelicopterCars,
-        VirginiaReelTubs,
-        ReverserCars,
-        Golfers,
-        RiverRideBoats,
-        FlyingRollerCoasterTrain,
-        NonLoopingSteelTwisterRollerCoasterTrain,
-        HeartlineTwisterCars,
-        HeartlineTwisterCarsReversed,
-        Reserved,
-        RotodropCar,
-        FlyingSaucers,
-        CrookedHouseBuilding,
-        Bicycles,
-        HypercoasterTrain,
+        steelRollerCoasterTrain,
+        steelRollerCoasterTrainBackwards,
+        woodenRollerCoasterTrain,
+        invertedCoasterTrain, // Not in RCT2
+        suspendedSwingingCars,
+        ladybirdCars,
+        standUpRollerCoasterCars,
+        spinningCars,
+        singlePersonSwingingChairs,
+        swansPedalBoats,
+        largeMonorailTrain,
+        canoes,
+        rowingBoats,
+        steamTrain,
+        woodenMouseCars,
+        bumperBoats,
+        woodenRollerCoasterTrainBackwards,
+        rocketCars,
+        horses, // Steeplechase
+        sportscars,
+        lyingDownSwingingCars, // Inverted single-rail
+        woodenMineCars,
+        suspendedSwingingAirplaneCars,
+        smallMonorailCars,
+        waterTricycles,
+        launchedFreefallCar,
+        bobsleighCars,
+        dinghies,
+        rotatingCabin,
+        mineTrain,
+        chairliftCars,
+        corkscrewRollerCoasterTrain,
+        motorbikes,
+        racingCars,
+        trucks,
+        goKarts,
+        rapidsBoats,
+        logFlumeBoats,
+        dodgems,
+        swingingShip,
+        swingingInverterShip,
+        merryGoRound,
+        ferrisWheel,
+        simulatorPod,
+        cinemaBuilding,
+        topspinCar,
+        spaceRings,
+        reverseFreefallRollerCoasterCar,
+        verticalRollerCoasterCars,
+        catCars,
+        twistArmsAndCars,
+        hauntedHouseBuilding,
+        logCars,
+        circusTent,
+        ghostTrainCars,
+        steelTwisterRollerCoasterTrain,
+        woodenTwisterRollerCoasterTrain,
+        woodenSideFrictionCars,
+        vintageCars,
+        steamTrainCoveredCars,
+        standUpSteelTwisterRollerCoasterTrain,
+        floorlessSteelTwisterRollerCoasterTrain,
+        steelMouseCars,
+        chairliftCarsAlternative,
+        suspendedMonorailTrain,
+        helicopterCars,
+        virginiaReelTubs,
+        reverserCars,
+        golfers,
+        riverRideBoats,
+        flyingRollerCoasterTrain,
+        nonLoopingSteelTwisterRollerCoasterTrain,
+        heartlineTwisterCars,
+        heartlineTwisterCarsReversed,
+        reserved,
+        rotodropCar,
+        flyingSaucers,
+        crookedHouseBuilding,
+        bicycles,
+        hypercoasterTrain,
         _4AcrossInvertedCoasterTrain,
-        WaterCoasterBoats,
-        FaceoffCars,
-        JetSkis,
-        RaftBoats,
-        AmericanStyleSteamTrain,
-        AirPoweredCoasterTrain,
-        SuspendedWildMouseCars, // Inverted Hairpin in RCT2
-        EnterpriseWheel,
+        waterCoasterBoats,
+        faceoffCars,
+        jetSkis,
+        raftBoats,
+        americanStyleSteamTrain,
+        airPoweredCoasterTrain,
+        suspendedWildMouseCars, // Inverted Hairpin in RCT2
+        enterpriseWheel,
 
-        Count,
+        count,
     };
 
     enum class BannerType : uint8_t
     {
-        Plain = 0,
-        Jungle,
-        Roman,
-        Egyptian,
-        Mine,
-        Jurassic,
-        Oriental,
-        Snow,
-        Space,
+        plain = 0,
+        jungle,
+        roman,
+        egyptian,
+        mine,
+        jurassic,
+        oriental,
+        snow,
+        space,
 
-        Null = 255,
+        null = 255,
     };
 
 #pragma pack(push, 1)
@@ -517,41 +517,41 @@ namespace OpenRCT2::RCT1
 
     enum class PeepAnimationGroup : uint8_t
     {
-        Normal = 0,
-        Handyman = 1,
-        Mechanic = 2,
-        Security = 3,
-        EntertainerPanda = 4,
-        EntertainerTiger = 5,
-        EntertainerElephant = 6,
-        EntertainerRoman = 7,
-        EntertainerGorilla = 8,
-        EntertainerSnowman = 9,
-        EntertainerKnight = 10,
-        EntertainerAstronaut = 11,
-        IceCream = 12,
-        Chips = 13,
-        Burger = 14,
-        Drink = 15,
-        Balloon = 16,
-        Candyfloss = 17,
-        Umbrella = 18,
-        Pizza = 19,
-        SecurityAlt = 20,
-        Popcorn = 21,
-        ArmsCrossed = 22,
-        HeadDown = 23,
-        Nauseous = 24,
-        VeryNauseous = 25,
-        RequireToilet = 26,
-        Hat = 27,
-        HotDog = 28,
-        Tentacle = 29,
-        ToffeeApple = 30,
-        Doughnut = 31,
-        Coffee = 32,
-        Chicken = 33,
-        Lemonade = 34,
+        normal = 0,
+        handyman = 1,
+        mechanic = 2,
+        security = 3,
+        entertainerPanda = 4,
+        entertainerTiger = 5,
+        entertainerElephant = 6,
+        entertainerRoman = 7,
+        entertainerGorilla = 8,
+        entertainerSnowman = 9,
+        entertainerKnight = 10,
+        entertainerAstronaut = 11,
+        iceCream = 12,
+        chips = 13,
+        burger = 14,
+        drink = 15,
+        balloon = 16,
+        candyfloss = 17,
+        umbrella = 18,
+        pizza = 19,
+        securityAlt = 20,
+        popcorn = 21,
+        armsCrossed = 22,
+        headDown = 23,
+        nauseous = 24,
+        veryNauseous = 25,
+        requireToilet = 26,
+        hat = 27,
+        hotDog = 28,
+        tentacle = 29,
+        toffeeApple = 30,
+        doughnut = 31,
+        coffee = 32,
+        chicken = 33,
+        lemonade = 34,
     };
 
     struct Peep : RCT12EntityBase
@@ -658,8 +658,16 @@ namespace OpenRCT2::RCT1
             uint8_t StaffOrders;         // 0xC6
             uint8_t PeepIsLostCountdown; // 0xC6
         };
-        RCT12RideId Photo1RideRef;     // 0xC7
-        uint32_t PeepFlags;            // 0xC8
+        RCT12RideId Photo1RideRef; // 0xC7
+        union
+        {
+            uint32_t peepFlagsLL; // 0xC8
+            struct
+            {
+                uint16_t peepFlagsBaseAA; // 0xC8
+                uint16_t itemFlagsBase;   // 0xCA
+            };
+        };
         RCT12xyzd8 PathfindGoal;       // 0xCC
         RCT12xyzd8 PathfindHistory[4]; // 0xD0
         uint8_t NoActionFrameNum;      // 0xE0
@@ -692,10 +700,15 @@ namespace OpenRCT2::RCT1
         RCT12RideId FavouriteRide;   // 0xF9
         uint8_t FavouriteRideRating; // 0xFA
         uint8_t PadFB;
-        uint32_t ItemStandardFlags; // 0xFC
-        uint64_t GetItemFlags() const
+        uint32_t itemFlagsAALL; // 0xFC
+
+        uint64_t GetItemFlags(bool isBase) const
         {
-            return ItemStandardFlags;
+            return isBase ? itemFlagsBase : itemFlagsAALL;
+        }
+        uint32_t getPeepFlags(bool isLL) const
+        {
+            return isLL ? peepFlagsLL : peepFlagsBaseAA;
         }
     };
     static_assert(sizeof(Peep) == 0x100);
