@@ -38,13 +38,13 @@ constexpr RideTypeDescriptor ReverserRollerCoasterRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE),
     .Heights = { 18, 24, 8, 11, },
     .MaxMass = 15,
-    .LiftData = { Audio::SoundId::LiftWood, 3, 5 },
+    .LiftData = { Audio::SoundId::liftWood, 3, 5 },
     .RatingsMultipliers = { 48, 28, 7 },
     .UpkeepCosts = { 39, 20, 80, 10, 3, 10 },
     .BuildCosts = { 27.50_GBP, 3.00_GBP, 37, },
     .DefaultPrices = { 20, 20 },
     .DefaultMusic = kMusicObjectTechno,
-    .PhotoItem = ShopItem::Photo3,
+    .PhotoItem = ShopItem::photo3,
     .BonusValue = 65,
     .ColourPresets = TRACK_COLOUR_PRESETS(
         { COLOUR_DARK_BROWN, COLOUR_LIGHT_BROWN, COLOUR_DARK_BROWN },
