@@ -40,13 +40,13 @@ constexpr RideTypeDescriptor FlyingSaucersRTD =
     .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT),
     .Heights = { 9, 48, 2, 2, },
     .MaxMass = 255,
-    .LiftData = { Audio::SoundId::Null, 5, 5 },
+    .LiftData = { Audio::SoundId::null, 5, 5 },
     .RatingsMultipliers = { 50, 25, 0 },
     .UpkeepCosts = { 90, 1, 0, 5, 0, 0 },
     .BuildCosts = { 35.00_GBP, 2.00_GBP, 1, },
     .DefaultPrices = { 15, 0 },
     .DefaultMusic = kMusicObjectRock1,
-    .PhotoItem = ShopItem::Photo,
+    .PhotoItem = ShopItem::photo,
     .BonusValue = 35,
     .ColourPresets = TRACK_COLOUR_PRESETS(
         { COLOUR_DARK_PURPLE, COLOUR_GREY, COLOUR_BLACK },
