@@ -83,7 +83,7 @@ void ScenarioBegin(GameState_t& gameState)
     ScenarioReset(gameState);
 
     if (gameState.scenarioOptions.objective.Type != ObjectiveType::none && !gLoadKeepWindowsOpen)
-        ContextOpenWindowView(WV_PARK_OBJECTIVE);
+        ContextOpenWindowView(WindowView::parkObjective);
 
     gScreenAge = 0;
 }
@@ -102,9 +102,9 @@ void ScenarioReset(GameState_t& gameState)
     News::InitQueue(gameState);
 
     auto& park = gameState.park;
-    park.rating = Park::CalculateParkRating();
-    park.value = Park::CalculateParkValue();
-    park.companyValue = Park::CalculateCompanyValue();
+    park.rating = Park::CalculateParkRating(park, gameState);
+    park.value = Park::CalculateParkValue(park, gameState);
+    park.companyValue = Park::CalculateCompanyValue(park);
     park.historicalProfit = gameState.scenarioOptions.initialCash - park.bankLoan;
     park.cash = gameState.scenarioOptions.initialCash;
 
@@ -138,7 +138,7 @@ void ScenarioReset(GameState_t& gameState)
     ResetAllRideBuildDates();
     ResetDate();
     Duck::RemoveAll();
-    Park::UpdateSize(gameState);
+    Park::UpdateSize(park);
     MapCountRemainingLandRights();
     Staff::ResetStats();
 
@@ -168,10 +168,10 @@ static void ScenarioEnd()
     GameResetSpeed();
 
     auto* windowMgr = Ui::GetWindowManager();
-    windowMgr->CloseByClass(WindowClass::Dropdown);
-    windowMgr->CloseAllExceptFlags(WF_STICK_TO_BACK | WF_STICK_TO_FRONT);
+    windowMgr->CloseByClass(WindowClass::dropdown);
+    windowMgr->CloseAllExceptFlags({ WindowFlag::stickToBack, WindowFlag::stickToFront });
 
-    ContextOpenWindowView(WV_PARK_OBJECTIVE);
+    ContextOpenWindowView(WindowView::parkObjective);
 }
 
 /**
@@ -235,7 +235,7 @@ static void ScenarioCheckEntranceFeeTooHigh()
             auto y = entrance.y + 16;
 
             uint32_t packed_xy = (y << 16) | x;
-            if (Config::Get().notifications.ParkWarnings)
+            if (Config::Get().notifications.parkWarnings)
             {
                 News::AddItemToQueue(News::ItemType::blank, STR_ENTRANCE_FEE_TOO_HI, packed_xy, {});
             }
@@ -254,7 +254,7 @@ void ScenarioAutosaveCheck()
     bool shouldSave = false;
     using namespace std::chrono_literals;
 
-    switch (Config::Get().general.AutosaveFrequency)
+    switch (Config::Get().general.autosaveFrequency)
     {
         case AUTOSAVE_EVERY_MINUTE:
             shouldSave = timeSinceSave >= std::chrono::milliseconds(1min).count();
@@ -352,7 +352,7 @@ static void ScenarioUpdateDayNightCycle()
     float currentDayNightCycle = gDayNightCycle;
     gDayNightCycle = 0;
 
-    if (gLegacyScene == LegacyScene::playing && Config::Get().general.DayNightCycle)
+    if (gLegacyScene == LegacyScene::playing && Config::Get().general.dayNightCycle)
     {
         float monthFraction = GetDate().GetMonthTicks() / static_cast<float>(kTicksPerMonth);
         if (monthFraction < (1 / 8.0f))
@@ -530,7 +530,7 @@ static ResultWithMessage ScenarioPrepareRidesForSave(GameState_t& gameState)
     bool isFiveCoasterObjective = gameState.scenarioOptions.objective.Type == ObjectiveType::finishFiveRollercoasters;
     uint8_t rcs = 0;
 
-    for (auto& ride : GetRideManager())
+    for (auto& ride : RideManager(gameState))
     {
         const auto* rideEntry = ride.getRideEntry();
         if (rideEntry != nullptr)
@@ -607,20 +607,21 @@ ResultWithMessage ScenarioPrepareForSave(GameState_t& gameState)
  */
 bool AllowEarlyCompletion()
 {
-    switch (NetworkGetMode())
+    switch (Network::GetMode())
     {
-        case NETWORK_MODE_CLIENT:
+        case Network::Mode::client:
             return gAllowEarlyCompletionInNetworkPlay;
-        case NETWORK_MODE_NONE:
-        case NETWORK_MODE_SERVER:
+        case Network::Mode::none:
+        case Network::Mode::server:
         default:
-            return Config::Get().general.AllowEarlyCompletion;
+            return Config::Get().general.allowEarlyCompletion;
     }
 }
 
 static void ScenarioCheckObjective(GameState_t& gameState)
 {
-    auto status = gameState.scenarioOptions.objective.Check(gameState);
+    auto& park = gameState.park;
+    auto status = gameState.scenarioOptions.objective.Check(park, gameState);
     if (status == ObjectiveStatus::Success)
     {
         ScenarioSuccess(gameState);
