@@ -27,9 +27,11 @@
     #include "../interface/InteractiveConsole.h"
     #include "../platform/Platform.h"
     #include "Duktape.hpp"
+    #include "bindings/entity/ScBalloon.hpp"
     #include "bindings/entity/ScEntity.hpp"
     #include "bindings/entity/ScGuest.hpp"
     #include "bindings/entity/ScLitter.hpp"
+    #include "bindings/entity/ScMoneyEffect.hpp"
     #include "bindings/entity/ScParticle.hpp"
     #include "bindings/entity/ScPeep.hpp"
     #include "bindings/entity/ScStaff.hpp"
@@ -49,6 +51,7 @@
     #include "bindings/object/ScObjectManager.h"
     #include "bindings/ride/ScRide.hpp"
     #include "bindings/ride/ScRideStation.hpp"
+    #include "bindings/world/ScAward.hpp"
     #include "bindings/world/ScClimate.hpp"
     #include "bindings/world/ScDate.hpp"
     #include "bindings/world/ScMap.hpp"
@@ -401,6 +404,7 @@ void ScriptEngine::Initialise()
         throw std::runtime_error("Script engine already initialised.");
 
     auto ctx = static_cast<duk_context*>(_context);
+    ScAward::Register(ctx);
     ScCheats::Register(ctx);
     ScClimate::Register(ctx);
     ScWeatherState::Register(ctx);
@@ -438,6 +442,8 @@ void ScriptEngine::Initialise()
     ScTrackSegment::Register(ctx);
     ScEntity::Register(ctx);
     ScLitter::Register(ctx);
+    ScBalloon::Register(ctx);
+    ScMoneyEffect::Register(ctx);
     ScVehicle::Register(ctx);
     ScCrashedVehicleParticle::Register(ctx);
     ScPeep::Register(ctx);
@@ -582,7 +588,7 @@ void ScriptEngine::RefreshPlugins()
     }
 
     // Turn on hot reload if not already enabled
-    if (!_hotReloadingInitialised && Config::Get().plugin.EnableHotReloading && NetworkGetMode() == NETWORK_MODE_NONE)
+    if (!_hotReloadingInitialised && Config::Get().plugin.enableHotReloading && Network::GetMode() == Network::Mode::none)
     {
         SetupHotReloading();
     }
@@ -592,7 +598,7 @@ std::vector<std::string> ScriptEngine::GetPluginFiles() const
 {
     // Scan for .js files in plugin directory
     std::vector<std::string> pluginFiles;
-    auto base = _env.GetDirectoryPath(DIRBASE::USER, DIRID::PLUGIN);
+    auto base = _env.GetDirectoryPath(DirBase::user, DirId::plugins);
     if (Path::DirectoryExists(base))
     {
         auto pattern = Path::Combine(base, u8"*.js");
@@ -794,7 +800,7 @@ void ScriptEngine::SetupHotReloading()
 {
     try
     {
-        auto base = _env.GetDirectoryPath(DIRBASE::USER, DIRID::PLUGIN);
+        auto base = _env.GetDirectoryPath(DirBase::user, DirId::plugins);
         if (Path::DirectoryExists(base))
         {
             _pluginFileWatcher = std::make_unique<FileWatcher>(base);
@@ -902,8 +908,8 @@ void ScriptEngine::StartTransientPlugins()
 
 bool ScriptEngine::ShouldStartPlugin(const std::shared_ptr<Plugin>& plugin)
 {
-    auto networkMode = NetworkGetMode();
-    if (networkMode == NETWORK_MODE_CLIENT)
+    auto networkMode = Network::GetMode();
+    if (networkMode == Network::Mode::client)
     {
         // Only client plugins and plugins downloaded from server should be started
         const auto& metadata = plugin->GetMetadata();
@@ -1066,7 +1072,7 @@ void ScriptEngine::RemoveNetworkPlugins()
     }
 }
 
-GameActions::Result ScriptEngine::QueryOrExecuteCustomGameAction(const CustomAction& customAction, bool isExecute)
+GameActions::Result ScriptEngine::QueryOrExecuteCustomGameAction(const GameActions::CustomAction& customAction, bool isExecute)
 {
     std::string actionz = customAction.GetId();
     auto kvp = _customActions.find(actionz);
@@ -1137,7 +1143,7 @@ GameActions::Result ScriptEngine::DukToGameActionResult(const DukValue& d)
         if (!expenditureType.empty())
         {
             auto expenditure = StringToExpenditureType(expenditureType);
-            if (expenditure != ExpenditureType::Count)
+            if (expenditure != ExpenditureType::count)
             {
                 result.Expenditure = expenditure;
             }
@@ -1186,10 +1192,10 @@ ExpenditureType ScriptEngine::StringToExpenditureType(std::string_view expenditu
     {
         return static_cast<ExpenditureType>(std::distance(std::begin(ExpenditureTypes), it));
     }
-    return ExpenditureType::Count;
+    return ExpenditureType::count;
 }
 
-DukValue ScriptEngine::GameActionResultToDuk(const GameAction& action, const GameActions::Result& result)
+DukValue ScriptEngine::GameActionResultToDuk(const GameActions::GameAction& action, const GameActions::Result& result)
 {
     DukStackFrame frame(_context);
     DukObject obj(_context);
@@ -1209,7 +1215,7 @@ DukValue ScriptEngine::GameActionResultToDuk(const GameAction& action, const Gam
     {
         obj.Set("position", ToDuk(_context, result.Position));
     }
-    if (result.Expenditure != ExpenditureType::Count)
+    if (result.Expenditure != ExpenditureType::count)
     {
         obj.Set("expenditureType", ExpenditureTypeToString(result.Expenditure));
     }
@@ -1228,7 +1234,7 @@ DukValue ScriptEngine::GameActionResultToDuk(const GameAction& action, const Gam
     {
         if (result.Error == GameActions::Status::Ok)
         {
-            const auto actionResult = result.GetData<StaffHireNewActionResult>();
+            const auto actionResult = result.GetData<GameActions::StaffHireNewActionResult>();
             if (!actionResult.StaffEntityId.IsNull())
             {
                 obj.Set("peep", actionResult.StaffEntityId.ToUnderlying());
@@ -1240,13 +1246,13 @@ DukValue ScriptEngine::GameActionResultToDuk(const GameAction& action, const Gam
     switch (action.GetType())
     {
         case GameCommand::PlaceBanner:
-            bannerId = result.GetData<BannerPlaceActionResult>().bannerId;
+            bannerId = result.GetData<GameActions::BannerPlaceActionResult>().bannerId;
             break;
         case GameCommand::PlaceLargeScenery:
-            bannerId = result.GetData<LargeSceneryPlaceActionResult>().bannerId;
+            bannerId = result.GetData<GameActions::LargeSceneryPlaceActionResult>().bannerId;
             break;
         case GameCommand::PlaceWall:
-            bannerId = result.GetData<WallPlaceActionResult>().BannerId;
+            bannerId = result.GetData<GameActions::WallPlaceActionResult>().BannerId;
             break;
         default:
             break;
@@ -1292,7 +1298,7 @@ void ScriptEngine::RemoveCustomGameActions(const std::shared_ptr<Plugin>& plugin
     }
 }
 
-class DukToGameActionParameterVisitor : public GameActionParameterVisitor
+class DukToGameActionParameterVisitor : public GameActions::GameActionParameterVisitor
 {
 private:
     DukValue _dukValue;
@@ -1319,7 +1325,7 @@ public:
     }
 };
 
-class DukFromGameActionParameterVisitor : public GameActionParameterVisitor
+class DukFromGameActionParameterVisitor : public GameActions::GameActionParameterVisitor
 {
 private:
     DukObject& _dukObject;
@@ -1358,7 +1364,6 @@ const static EnumMap<GameCommand> ActionNameToType = {
     { "bannersetname", GameCommand::SetBannerName },
     { "bannersetstyle", GameCommand::SetBannerStyle },
     { "clearscenery", GameCommand::ClearScenery },
-    { "climateset", GameCommand::SetClimate },
     { "footpathplace", GameCommand::PlacePath },
     { "footpathlayoutplace", GameCommand::PlacePathLayout },
     { "footpathremove", GameCommand::RemovePath },
@@ -1446,7 +1451,7 @@ static std::string GetActionName(GameCommand commandId)
     return {};
 }
 
-static std::unique_ptr<GameAction> CreateGameActionFromActionId(const std::string& name)
+static std::unique_ptr<GameActions::GameAction> CreateGameActionFromActionId(const std::string& name)
 {
     auto result = ActionNameToType.find(name);
     if (result != ActionNameToType.end())
@@ -1456,11 +1461,11 @@ static std::unique_ptr<GameAction> CreateGameActionFromActionId(const std::strin
     return nullptr;
 }
 
-void ScriptEngine::RunGameActionHooks(const GameAction& action, GameActions::Result& result, bool isExecute)
+void ScriptEngine::RunGameActionHooks(const GameActions::GameAction& action, GameActions::Result& result, bool isExecute)
 {
     DukStackFrame frame(_context);
 
-    auto hookType = isExecute ? HOOK_TYPE::ACTION_EXECUTE : HOOK_TYPE::ACTION_QUERY;
+    auto hookType = isExecute ? HookType::actionExecute : HookType::actionQuery;
     if (_hookEngine.HasSubscriptions(hookType))
     {
         DukObject obj(_context);
@@ -1468,7 +1473,7 @@ void ScriptEngine::RunGameActionHooks(const GameAction& action, GameActions::Res
         auto actionId = action.GetType();
         if (action.GetType() == GameCommand::Custom)
         {
-            auto customAction = static_cast<const CustomAction&>(action);
+            auto customAction = static_cast<const GameActions::CustomAction&>(action);
             obj.Set("action", customAction.GetId());
 
             auto dukArgs = DuktapeTryParseJson(_context, customAction.GetJson());
@@ -1492,8 +1497,8 @@ void ScriptEngine::RunGameActionHooks(const GameAction& action, GameActions::Res
 
             DukObject args(_context);
             DukFromGameActionParameterVisitor visitor(args);
-            const_cast<GameAction&>(action).AcceptParameters(visitor);
-            const_cast<GameAction&>(action).AcceptFlags(visitor);
+            const_cast<GameActions::GameAction&>(action).AcceptParameters(visitor);
+            const_cast<GameActions::GameAction&>(action).AcceptFlags(visitor);
             obj.Set("args", args.Take());
         }
 
@@ -1525,7 +1530,7 @@ void ScriptEngine::RunGameActionHooks(const GameAction& action, GameActions::Res
     }
 }
 
-std::unique_ptr<GameAction> ScriptEngine::CreateGameAction(
+std::unique_ptr<GameActions::GameAction> ScriptEngine::CreateGameAction(
     const std::string& actionid, const DukValue& args, const std::string& pluginName)
 {
     auto action = CreateGameActionFromActionId(actionid);
@@ -1554,11 +1559,11 @@ std::unique_ptr<GameAction> ScriptEngine::CreateGameAction(
     auto jsonz = duk_json_encode(ctx, -1);
     auto json = std::string(jsonz);
     duk_pop(ctx);
-    auto customAction = std::make_unique<CustomAction>(actionid, json, pluginName);
+    auto customAction = std::make_unique<GameActions::CustomAction>(actionid, json, pluginName);
 
-    if (customAction->GetPlayer() == -1 && NetworkGetMode() != NETWORK_MODE_NONE)
+    if (customAction->GetPlayer() == -1 && Network::GetMode() != Network::Mode::none)
     {
-        customAction->SetPlayer(NetworkGetCurrentPlayerId());
+        customAction->SetPlayer(Network::GetCurrentPlayerId());
     }
     return customAction;
 }
@@ -1573,7 +1578,7 @@ void ScriptEngine::LoadSharedStorage()
 {
     InitSharedStorage();
 
-    auto path = _env.GetFilePath(PATHID::PLUGIN_STORE);
+    auto path = _env.GetFilePath(PathId::pluginStore);
     try
     {
         if (File::Exists(path))
@@ -1595,7 +1600,7 @@ void ScriptEngine::LoadSharedStorage()
 
 void ScriptEngine::SaveSharedStorage()
 {
-    auto path = _env.GetFilePath(PATHID::PLUGIN_STORE);
+    auto path = _env.GetFilePath(PathId::pluginStore);
     try
     {
         _sharedStorage.push();
@@ -1812,7 +1817,7 @@ std::string OpenRCT2::Scripting::ProcessString(const DukValue& value)
 bool OpenRCT2::Scripting::IsGameStateMutable()
 {
     // Allow single player to alter game state anywhere
-    if (NetworkGetMode() == NETWORK_MODE_NONE)
+    if (Network::GetMode() == Network::Mode::none)
     {
         return true;
     }
@@ -1825,7 +1830,7 @@ bool OpenRCT2::Scripting::IsGameStateMutable()
 void OpenRCT2::Scripting::ThrowIfGameStateNotMutable()
 {
     // Allow single player to alter game state anywhere
-    if (NetworkGetMode() != NETWORK_MODE_NONE)
+    if (Network::GetMode() != Network::Mode::none)
     {
         auto& scriptEngine = GetContext()->GetScriptEngine();
         auto& execInfo = scriptEngine.GetExecInfo();
