@@ -97,7 +97,7 @@ namespace OpenRCT2::Scripting
         {
             auto spriteId = EntityId::FromUnderlying(id);
             auto sprite = getGameState().entities.GetEntity(spriteId);
-            if (sprite != nullptr && sprite->Type != EntityType::Null)
+            if (sprite != nullptr && sprite->Type != EntityType::null)
             {
                 return GetEntityAsDukValue(sprite);
             }
@@ -190,13 +190,13 @@ namespace OpenRCT2::Scripting
                 {
                     switch (staff->AssignedStaffType)
                     {
-                        case StaffType::Handyman:
+                        case StaffType::handyman:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(sprite->Id)));
                             break;
-                        case StaffType::Mechanic:
+                        case StaffType::mechanic:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(sprite->Id)));
                             break;
-                        case StaffType::Security:
+                        case StaffType::security:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(sprite->Id)));
                             break;
                         default:
@@ -286,13 +286,13 @@ namespace OpenRCT2::Scripting
                 {
                     switch (staff->AssignedStaffType)
                     {
-                        case StaffType::Handyman:
+                        case StaffType::handyman:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(sprite->Id)));
                             break;
-                        case StaffType::Mechanic:
+                        case StaffType::mechanic:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(sprite->Id)));
                             break;
-                        case StaffType::Security:
+                        case StaffType::security:
                             result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(sprite->Id)));
                             break;
                         default:
@@ -456,20 +456,20 @@ namespace OpenRCT2::Scripting
         auto spriteId = sprite->Id;
         switch (sprite->Type)
         {
-            case EntityType::Vehicle:
+            case EntityType::vehicle:
                 return GetObjectAsDukValue(_context, std::make_shared<ScVehicle>(spriteId));
-            case EntityType::Staff:
+            case EntityType::staff:
             {
                 auto staff = getGameState().entities.GetEntity<Staff>(spriteId);
                 if (staff != nullptr)
                 {
                     switch (staff->AssignedStaffType)
                     {
-                        case StaffType::Handyman:
+                        case StaffType::handyman:
                             return GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(spriteId));
-                        case StaffType::Mechanic:
+                        case StaffType::mechanic:
                             return GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(spriteId));
-                        case StaffType::Security:
+                        case StaffType::security:
                             return GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(spriteId));
                         default:
                             return GetObjectAsDukValue(_context, std::make_shared<ScStaff>(spriteId));
@@ -480,15 +480,15 @@ namespace OpenRCT2::Scripting
                     return GetObjectAsDukValue(_context, std::make_shared<ScStaff>(spriteId));
                 }
             }
-            case EntityType::Guest:
+            case EntityType::guest:
                 return GetObjectAsDukValue(_context, std::make_shared<ScGuest>(spriteId));
-            case EntityType::Litter:
+            case EntityType::litter:
                 return GetObjectAsDukValue(_context, std::make_shared<ScLitter>(spriteId));
-            case EntityType::Balloon:
+            case EntityType::balloon:
                 return GetObjectAsDukValue(_context, std::make_shared<ScBalloon>(spriteId));
-            case EntityType::MoneyEffect:
+            case EntityType::moneyEffect:
                 return GetObjectAsDukValue(_context, std::make_shared<ScMoneyEffect>(spriteId));
-            case EntityType::CrashedVehicleParticle:
+            case EntityType::crashedVehicleParticle:
                 return GetObjectAsDukValue(_context, std::make_shared<ScCrashedVehicleParticle>(spriteId));
             default:
                 return GetObjectAsDukValue(_context, std::make_shared<ScEntity>(spriteId));
